From 39d25d9dfede3d992f8c27dca3d75ec4db62d3c1 Mon Sep 17 00:00:00 2001
From: Michael Chan <michael.chan@broadcom.com>
Date: Tue, 9 Jul 2019 18:57:41 -0400
Subject: [PATCH] bnxt_en: Fix unresolved vxlan_get_rx_port() error on RHEL7.7.

Some RHEL7.x kernels don't have vxlan_get_rx_port() defined.  Fix it
in Makefile and bnxt_compat.h

Bug: CTRL-30332
Change-Id: I5410797f7e303921c70bf471bf1eb538c413cafb
Signed-off-by: Michael Chan <michael.chan@broadcom.com>
Reviewed-on: http://gerrit-ccxsw.broadcom.net/96254
Tested-by: Ccxsw Build <ccxsw.build@broadcom.com>
Reviewed-by: Pavan Chebbi <pavan.chebbi@broadcom.com>
---
 v3/Makefile      | 3 +++
 v3/bnxt_compat.h | 8 ++++++++
 2 files changed, 11 insertions(+)

diff --git a/v3/Makefile b/v3/Makefile
index 65f0fca4a..7a2c22cb8 100644
--- a/v3/Makefile
+++ b/v3/Makefile
@@ -186,6 +186,9 @@ endif
 
 ifneq ($(shell grep -o "ndo_add_vxlan_port" $(LINUXSRC)/include/linux/netdevice.h),)
   DISTRO_CFLAG += -DHAVE_NDO_ADD_VXLAN
+  ifneq ($(shell grep -so "vxlan_get_rx_port" $(LINUXSRC)/include/net/vxlan.h),)
+    DISTRO_CFLAG += -DHAVE_VXLAN_GET_RX_PORT
+  endif
 endif
 
 ifneq ($(shell grep -o "struct dev_addr_list" $(LINUXSRC)/include/linux/netdevice.h),)
diff --git a/v3/bnxt_compat.h b/v3/bnxt_compat.h
index 03101aa11..cf498571d 100644
--- a/v3/bnxt_compat.h
+++ b/v3/bnxt_compat.h
@@ -1313,3 +1313,11 @@ static inline void devlink_params_publish(struct devlink *devlink)
 #ifndef HAVE_NETDEV_XMIT_MORE
 #define netdev_xmit_more()	skb->xmit_more
 #endif
+
+#ifdef HAVE_NDO_ADD_VXLAN
+#ifndef HAVE_VXLAN_GET_RX_PORT
+static inline void vxlan_get_rx_port(struct net_device *netdev)
+{
+}
+#endif
+#endif
-- 
2.21.0

